# Creation of the remote doctype

The remote doctype should be created in the cozy repo : [https://github.com/cozy/cozy-doctypes](https://github.com/cozy/cozy-doctypes)

## Remote doctype org.ecolyo.usage

To create the remote the first create a folder named 'org.ecolyo.usage' and then add a file named _request_ in the folder.

Here is the structure of the file:

```bash
POST https://API_URL
Content-Type: application/json

{{data}}
```

## Local remote doctype

As the doctype if not yet avaible on cozy repo, we first need to test it on local. For that we can use the _—doctypes_ command in the cozy-stack serve and use it to point to a local repo.

Here are the step:

- clone the repo and add it in the ecolyo repo
- create the remote doctype. Here we create a new folder named 'org.ecolyo.usage' and add the following request file (replace API_URL by the url of the API):

```bash
POST https://API_URL
Content-Type: application/json

{{data}}
```

- add the _—doctypes_ command in the "docker/cozy-app-dev-with-app.sh" file and also the _-remote-allow-custom-port_ flag

```bash
${COZY_STACK_PATH} serve --allow-root \
                --appdir "${appdir}" \
                --host "::" \
                --port "${COZY_STACK_PORT}" \
                --admin-port "${COZY_STACK_ADMIN_PORT}" \
                --couchdb-url "${COUCHDB_URL}" \
                --doctypes /data/cozy-doctypes \
                --mail-port 1025 \
                --mail-disable-tls \
                --remote-allow-custom-port \
                --fs-url "file://localhost${vfsdir}" &
```

- add the following content in "docker/disableCSP.yaml":

```yaml
remote_assets:
  ecolyo-usage: http://cozy.tools:8080/remote/org.ecolyo.usage/
```

- Go to the docker folder in the project root

```
cd docker
```

- build the docker image and tag it to [registry.forge.grandlyon.com/web-et-numerique/llle_project/ecolyo/cozy-env](http://registry.forge.grandlyon.com/web-et-numerique/llle_project/ecolyo/cozy-env):

```
docker build . -t registry.forge.grandlyon.com/web-et-numerique/llle_project/ecolyo/cozy-env
```

- Then add the following command to winstack script in the package.json:

```yaml
-v $PWD/cozy-doctypes:/data/cozy-doctypes
```

- start the server with the new image:

```bash
yarn winstack
```

- Change the content request param in io.cozy.doctypes/org.ecolyo.usage using the db tool ([http://localhost:5984/\_utils](http://localhost:5984/_utils)):

```bash
"request": "POST https://API_URL\nContent-Type: application/json\n\n{{data}}",
```

# Use of remote doctype in the application

Add permission in manifest.webapp

```json
"ecolyo-usage": {
  "type": "org.ecolyo.usage",
  "verbs": ["GET", "POST"]
}
```

Don't forget to add the description

Call the remote docType:

```jsx
const result = await client
    .getStackClient()
    .fetchJSON('POST', '/remote/org.ecolyo.usage', {
      JSON.stringify(indicator),
    })
```

## Passing parameters to a remote doctype

In order to pass parameters to a remote doctypes such as query paramaters or headers, you need to process the following way :

You can pass header directly under the URL in the _request_ file, such as Authorization or Content-Type headers.

```bash
GET https://API_URL/?q={queryParam}
Authorization: Bearer {{secret_token}}
Content-Type: application/json

```

When you call the remote doctype, you can directly pass the parameters to the doctype :

```jsx
const result = await client
  .getStackClient()
  .fetchJSON("GET", "/remote/org.ecolyo.usage/queryParam=yourParameter");
```

If you wanna know more about remote doctypes and how to store and use secret tokens, please refer to the official cozy documentation.
